==> codeaudit-0.9.2.tar.gz: codeaudit-0.9.2/docs/help.md <==
# Help

This Open Source tool is created to [simplifying cyber security](https://nocomplexity.com/documents/simplifysecurity/intro.html).

:::{hint} 
Everyone can help with improving this tool!

**All contributions are welcome! Think of corrections on the documentation, code or more tests.**

:::




Helping is possible in multiple ways:
* [Support this work](sponsors)
* Share and promote the use of this solid simple tool
* Send me a line that you use this tool within your company. 
* [Contribute](contribute)

Guideline to contribute:
* For questions, feature requests and Bug Reports please use on the [Github Issue Tracker](https://github.com/nocomplexity/codeaudit/issues).


## Support this work

This publication is open-access. So it's free to read, use and reuse as input for other publications.
I believe knowledge should be free and available for everyone on planet earth. 

:::{admonition} Donate
:class: tip

If you think this PlayBook is worth a few Euros, you can [buy ](https://nocomplexity.gumroad.com/) and receive the PDF version. This will help me to keep this guide maintained. If you are not able to make a small donation, it's fine. Just enjoy this PlayBook and [Share](share-subsection) the word about it.
:::


Become a sponsor for this project! Check [this page](sponsors) to increase your audience and discuss options.


:::{note} 
**Note: We only display ethical ads as static images. So no ad networks or tracking technologies are used.**
:::



(share-subsection)=
## Share this Guide on Python Source Code security

This guide on is created and published on the Internet to be shared as much as possible!

So Sharing is greatly appreciated!

:::{tip}
To share this publication , just share the URL: 

[https://nocomplexity.com/documents/codeaudit](https://nocomplexity.com/documents/codeaudit)

Or use copy-paste:
```
https://nocomplexity.com/documents/codeaudit
```
:::


This  Guide is last updated on:
{sub-ref}`today`.

==> codeaudit-1.2.0.tar.gz: codeaudit-1.2.0/docs/help.md <==
# Help

This Open Source tool is created to [simplifying cyber security](https://nocomplexity.com/documents/simplifysecurity/intro.html).

:::{hint} 
Everyone can help with improving this tool!

**All contributions are welcome! Think of corrections on the documentation, code or more tests.**

:::




Helping is possible in multiple ways:
* [Support this work](sponsors)
* Share and promote the use of this solid simple tool
* Send me a line that you use this tool within your company. 
* [Contribute](CONTRIBUTE)

Guideline to contribute:
* For questions, feature requests and Bug Reports please use on the [Github Issue Tracker](https://github.com/nocomplexity/codeaudit/issues).


## Support this work

This publication is open-access. So it's free to read, use and reuse as input for other publications.
I believe knowledge should be free and available for everyone on planet earth. 

:::{admonition} Donate
:class: tip

If you think this PlayBook is worth a few Euros, you can [buy ](https://nocomplexity.gumroad.com/) and receive the PDF version. This will help me to keep this guide maintained. If you are not able to make a small donation, it's fine. Just enjoy this PlayBook and [Share](share-subsection) the word about it.
:::


Become a sponsor for this project! Check [this page](sponsors) to increase your audience and discuss options.


:::{note} 
**Note: We only display ethical ads as static images. So no ad networks or tracking technologies are used.**
:::



(share-subsection)=
## Share this Guide on Python Source Code security

This guide on is created and published on the Internet to be shared as much as possible!

So Sharing is greatly appreciated!

:::{tip}
To share this publication , just share the URL: 

[https://nocomplexity.com/documents/codeaudit](https://nocomplexity.com/documents/codeaudit)

Or use copy-paste:
```
https://nocomplexity.com/documents/codeaudit
```
:::


This  Guide is last updated on:
{sub-ref}`today`.
